Expunge revision histories in files.
[u/mdw/catacomb] / mpmont.h
index 120fa92..b931162 100644 (file)
--- a/mpmont.h
+++ b/mpmont.h
@@ -1,6 +1,6 @@
 /* -*-c-*-
  *
- * $Id: mpmont.h,v 1.4 1999/12/11 01:51:14 mdw Exp $
+ * $Id: mpmont.h,v 1.8 2004/04/08 01:36:15 mdw Exp $
  *
  * Montgomery reduction
  *
  * MA 02111-1307, USA.
  */
 
-/*----- Revision history --------------------------------------------------* 
- *
- * $Log: mpmont.h,v $
- * Revision 1.4  1999/12/11 01:51:14  mdw
- * Use a Karatsuba-based reduction for large moduli.
- *
- * Revision 1.3  1999/12/10 23:29:48  mdw
- * Change header file guard names.
- *
- * Revision 1.2  1999/11/19 13:17:43  mdw
- * Add extra interface to exponentiation which returns a Montgomerized
- * result.  Add simultaneous exponentiation interface.
- *
- * Revision 1.1  1999/11/17 18:02:16  mdw
- * New multiprecision integer arithmetic suite.
- *
- */
-
 #ifndef CATACOMB_MPMONT_H
 #define CATACOMB_MPMONT_H
 
@@ -103,13 +85,6 @@ typedef struct mpmont {
   mp *r, *r2;                          /* %$R \bmod m$%, %$R^2 \bmod m$% */
 } mpmont;
 
-/* --- A base/exponent pair for @mpmont_mexp@ --- */
-
-typedef struct mpmont_factor {
-  mp *base;
-  mp *exp;
-} mpmont_factor;
-
 /*----- Functions provided ------------------------------------------------*/
 
 /* --- @mpmont_create@ --- *
@@ -166,8 +141,8 @@ extern mp *mpmont_mul(mpmont */*mm*/, mp */*d*/, mp */*a*/, mp */*b*/);
  *             @mp *a@ = base
  *             @mp *e@ = exponent
  *
- * Returns:    Result, %$a^e R \bmod m$%.  This is useful if further modular
- *             arithmetic is to be performed on the result.
+ * Returns:    Result, %$(a R^{-1})^e R \bmod m$%.  This is useful if
+ *             further modular arithmetic is to be performed on the result.
  */
 
 extern mp *mpmont_expr(mpmont */*mm*/, mp */*d*/, mp */*a*/, mp */*e*/);
@@ -188,24 +163,27 @@ extern mp *mpmont_exp(mpmont */*mm*/, mp */*d*/, mp */*a*/, mp */*e*/);
  *
  * Arguments:  @mpmont *mm@ = pointer to Montgomery reduction context
  *             @mp *d@ = fake destination
*             @mpmont_factor *f@ = pointer to array of factors
  *             @size_t n@ = number of factors supplied
  *
  * Returns:    If the bases are %$g_0, g_1, \ldots, g_{n-1}$% and the
  *             exponents are %$e_0, e_1, \ldots, e_{n-1}$% then the result
  *             is:
  *
- *             %$g_0^{e_0} g_1^{e_1} \ldots g_{n-1}^{e_{n-1}} R \bmod m$%
+ *             %$g_0^{e_0} g_1^{e_1} \ldots g_{n-1}^{e_{n-1}} \bmod m$%
+ *
+ *
+ *             except that the %$g_i$% and result are in Montgomery form.
  */
 
 extern mp *mpmont_mexpr(mpmont */*mm*/, mp */*d*/,
-                       mpmont_factor */*f*/, size_t /*n*/);
+                       const mp_expfactor */*f*/, size_t /*n*/);
 
 /* --- @mpmont_mexp@ --- *
  *
  * Arguments:  @mpmont *mm@ = pointer to Montgomery reduction context
  *             @mp *d@ = fake destination
*             @mpmont_factor *f@ = pointer to array of factors
  *             @size_t n@ = number of factors supplied
  *
  * Returns:    Product of bases raised to exponents, all mod @m@.
@@ -214,7 +192,7 @@ extern mp *mpmont_mexpr(mpmont */*mm*/, mp */*d*/,
  */
 
 extern mp *mpmont_mexp(mpmont */*mm*/, mp */*d*/,
-                      mpmont_factor */*f*/, size_t /*n*/);
+                      const mp_expfactor */*f*/, size_t /*n*/);
 
 /*----- That's all, folks -------------------------------------------------*/
@@ -188,24 +163,27 @@ extern mp *mpmont_exp(mpmont */*mm*/, mp */*d*/, mp */*a*/, mp */*e*/);
  * Arguments:  @mpmont *mm@ = pointer to Montgomery reduction context
  *             @mp *d@ = fake destination
- *             @mpmont_factor *f@ = pointer to array of factors
+ *             @const mp_expfactor *f@ = pointer to array of factors
  *             @size_t n@ = number of factors supplied
  *
@@ -188,24 +163,27 @@ extern mp *mpmont_exp(mpmont */*mm*/, mp */*d*/, mp */*a*/, mp */*e*/);
  * Arguments:  @mpmont *mm@ = pointer to Montgomery reduction context
  *             @mp *d@ = fake destination
- *             @mpmont_factor *f@ = pointer to array of factors
+ *             @const mp_expfactor *f@ = pointer to array of factors
  *             @size_t n@ = number of factors supplied
  *